@@ -29,7 +29,9 @@ cat tt | sort | uniq > coord.txt
 
 rm tt
 
-cat coord.txt | xargs -I {} -n 1 bash -c 'echo -e "samtools mpileup -DguS -f $1 -r {} -b bamlist.txt | bcftools view -bvcg - > tmpbcf/tmp.{}.bcf && bcftools view tmpbcf/tmp.{}.bcf > tmpbcf/tmp.{}.vcf\n"'
+#Lets shuffle the input to distribute it better
+
+cat coord.txt | shuf | xargs -I {} -n 1 bash -c 'echo -e "samtools mpileup -DguS -f $1 -r {} -b bamlist.txt | bcftools view -bvcg - > tmpbcf/tmp.{}.bcf && bcftools view tmpbcf/tmp.{}.bcf > tmpbcf/tmp.{}.vcf\n"'
 
 #Wait for these to finish
 echo -e "wait\n" 
